@@ -2,7 +2,7 @@ package Test2::IPC::Driver::Files;
 use strict;
 use warnings;
 
-our $VERSION = '0.000028';
+our $VERSION = '0.000029';
 
 use base 'Test2::IPC::Driver';
 
@@ -24,7 +24,11 @@ sub is_viable { 1 }
 sub init {
     my $self = shift;
 
-    my $tmpdir = File::Temp::tempdir($ENV{T2_TEMPDIR_TEMPLATE} || 'test2-XXXXXX', CLEANUP => 0, TMPDIR => 1);
+    my $tmpdir = File::Temp::tempdir(
+        $ENV{T2_TEMPDIR_TEMPLATE} || "test2-$$-XXXXXX",
+        CLEANUP => 0,
+        TMPDIR => 1,
+    );
 
     $self->abort_trace("Could not get a temp dir") unless $tmpdir;
 
